@@ -7,6 +7,8 @@
     Copyright (c) 2005 Etersoft
     Copyright (c) 2005 Vitaly Lipatov <lav@etersoft.ru>
 
+    $Id: natspec_internal.h,v 1.9 2005/02/23 15:03:27 lav Exp $
+
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
     License as published by the Free Software Foundation, version 2.1
@@ -41,18 +43,25 @@
 	#error "Some error"
 #endif
 
+/* Add n in next line for debug messaging */
 #define DEBUG(n)
 
+/* Extracts charset (if exist) from locale, removes punctiation
+ * signs from it, pack locale again
+ * and return malloc allocated locale string
+ */
 char *repack_locale(const char *locale);
 
+/* Struct of charset_relation table */
 struct charsetrel_entry
 {
-    const char *locale;
-    unsigned int lcid;
-    const char *unix_cs;
-    const char *win_cs;
-    const char *dos_cs;
-    const char *mac_cs;
+    const char *locale;	/* Unix locale name (from glibc) */
+    unsigned int lcid;	/* Windows locale id (from WINE) */
+			/* for this locale: (can be NULL) */
+    const char *unix_cs;  /* unix charset */
+    const char *win_cs;   /* windows charset */
+    const char *dos_cs;   /* dos charset */
+    const char *mac_cs;   /* mac charset */
 };
 
 
